summaryrefslogtreecommitdiffstats
path: root/src/include/runtime/interface.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/include/runtime/interface.h')
-rw-r--r--src/include/runtime/interface.h7
1 files changed, 3 insertions, 4 deletions
diff --git a/src/include/runtime/interface.h b/src/include/runtime/interface.h
index 7fa1e86fb..7fe940a99 100644
--- a/src/include/runtime/interface.h
+++ b/src/include/runtime/interface.h
@@ -549,11 +549,10 @@ typedef struct hostInterfaces
};
};
- // Created this enum to hold the base size of hbrt_fw_msg
+
+ // Created a static constexpr to return the base size of hbrt_fw_msg
// Can't do #define - sizeof not allowed to be used in #defines
- // Can't do a constant, if you do, you will need to create
- // an instance of this struct to get to it
- enum { HBRT_FW_MSG_BASE_SIZE = sizeof(uint64_t) };
+ static constexpr size_t HBRT_FW_MSG_BASE_SIZE = sizeof(uint64_t);
/**
* @brief Send a request to firmware, and receive a response
OpenPOWER on IntegriCloud